@@ -3,7 +3,7 @@ package Quiq;
 use strict;
 use warnings;
 
-our $VERSION = '1.158';
+our $VERSION = '1.159';
 
 =encoding utf8
 
@@ -48,6 +48,10 @@ L<Quiq::Cascm> - Schnittstelle zu CA Harvest SCM
 
 =item *
 
+L<Quiq::ChartJs::TimeSeries> - Zeitreihen-Plot via Chart.js
+
+=item *
+
 L<Quiq::ClassConfig> - Verwalte Information auf Klassenebene
 
 =item *
@@ -540,6 +544,10 @@ L<Quiq::Pod::Generator> - POD-Generator
 
 =item *
 
+L<Quiq::PostgreSql::Catalog> - PostgreSQL Catalog-Operationen
+
+=item *
+
 L<Quiq::PostgreSql::CopyFormat> - Erzeuge Daten für PostgreSQL COPY-Kommando
 
 =item *
@@ -742,7 +750,7 @@ L<Quiq::Xml::LibXml> - Funktionale Erweiterungen von XML::LibXML
 
 =head1 VERSION
 
-1.158
+1.159
 
 =head1 AUTHOR
 
