@@ -5,7 +5,7 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.158';
+our $VERSION = '1.159';
 
 use overload '""' => sub {${$_[0]}}, 'cmp' => sub{${$_[0]} cmp $_[1]};
 use Quiq::Path;
@@ -110,6 +110,10 @@ sub new {
     # Wir setzen unsere Optionen in die Optionen von File::Temp um
 
     my @args;
+    if (defined $dir) {
+        $dir = Quiq::Path->expandTilde($dir);
+        push @args,'DIR',$dir;
+    }
     if (defined $suffix) {
         push @args,'SUFFIX',$suffix;
     }
@@ -135,7 +139,7 @@ sub new {
 
 =head1 VERSION
 
-1.158
+1.159
 
 =head1 AUTHOR
 
